@@ -44,7 +44,7 @@ KAudiocdModule::KAudiocdModule(QWidget *parent, const char *name)
     config = new KConfig("kcmaudiocdrc");
 
     QPtrList<AudioCDEncoder> encoders;
-    AudioCDEncoder::find_all_plugins(0, encoders);
+    AudioCDEncoder::findAllPlugins(0, encoders);
     AudioCDEncoder *encoder;
     for ( encoder = encoders.first(); encoder; encoder = encoders.next() ){
       KConfigSkeleton *config = NULL;
@@ -64,10 +64,11 @@ KAudiocdModule::KAudiocdModule(QWidget *parent, const char *name)
     }
    
     //CDDA Options
-    connect(cd_autosearch_check,SIGNAL(clicked()),this,SLOT(slotConfigChanged()));
+    connect(cd_specify_device,SIGNAL(clicked()),this,SLOT(slotConfigChanged()));
     connect(ec_enable_check,SIGNAL(clicked()),this,SLOT(slotEcEnable()));
     connect(ec_skip_check,SIGNAL(clicked()),SLOT(slotConfigChanged()));
     connect(cd_device_string,SIGNAL(textChanged(const QString &)),SLOT(slotConfigChanged()));
+    connect(niceLevel,SIGNAL(valueChanged(int)),SLOT(slotConfigChanged()));
 
     // File Name
     connect(fileNameLineEdit, SIGNAL(textChanged(const QString &)), this, SLOT(slotConfigChanged()));
@@ -99,23 +100,7 @@ void KAudiocdModule::updateExample()
 }
 
 void KAudiocdModule::defaults() {
-	cd_autosearch_check->setChecked(true);
-	cd_device_string->setText("/dev/cdrom");
-
-	ec_enable_check->setChecked(true);
-	ec_skip_check->setChecked(false);
-	niceLevel->setValue(0);
-	
-	kcfg_replaceInput->setText("");
-	kcfg_replaceOutput->setText("");
-	example->setText(i18n("Cool artist - example audio file.wav"));
-	KConfigDialogManager *widget;
-	for ( widget = encoderSettings.first(); widget; widget = encoderSettings.next() ){
-		widget->updateWidgetsDefault();
-	}
-
-	fileNameLineEdit->setText("%{albumartist} - %{number} - %{title}");
-	albumNameLineEdit->setText("%{albumartist} - %{albumtitle}");
+	load( false );
 }
 
 void KAudiocdModule::save() {
@@ -124,7 +109,11 @@ void KAudiocdModule::save() {
   {
     KConfigGroupSaver saver(config, "CDDA");
 
-    config->writeEntry("autosearch",cd_autosearch_check->isChecked());
+    // autosearch is the name of the config option, which has the
+    // reverse sense of the current text of the configuration option,
+    // which is specify the device. Therefore, invert the value on write.
+    //
+    config->writeEntry("autosearch", !(cd_specify_device->isChecked()) );
     config->writeEntry("device",cd_device_string->text());
     config->writeEntry("disable_paranoia",!(ec_enable_check->isChecked()));
     config->writeEntry("never_skip",!(ec_skip_check->isChecked()));
@@ -152,11 +141,19 @@ void KAudiocdModule::save() {
 }
 
 void KAudiocdModule::load() {
+	load( false );
+}
+
+void KAudiocdModule::load(bool useDefaults) {
+
+	config->setReadDefaults( useDefaults );
 
   {
     KConfigGroupSaver saver(config, "CDDA");
 
-    cd_autosearch_check->setChecked(config->readBoolEntry("autosearch",true));
+
+    // Specify <=> not autosearch, as explained above in ::save()
+    cd_specify_device->setChecked( !(config->readBoolEntry("autosearch",true)) );
     cd_device_string->setText(config->readEntry("device","/dev/cdrom"));
     ec_enable_check->setChecked(!(config->readBoolEntry("disable_paranoia",false)));
     ec_skip_check->setChecked(!(config->readBoolEntry("never_skip",true)));
@@ -176,6 +173,8 @@ void KAudiocdModule::load() {
   for ( widget = encoderSettings.first(); widget; widget = encoderSettings.next() ){
     widget->updateWidgets();
   }
+
+  emit changed( useDefaults );
 }
 
 void KAudiocdModule::slotModuleChanged() {
