@@ -4,6 +4,7 @@
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  * Copyright (c) 2002-2003 Aaron J. Seigo <aseigo@kde.org>
  * Copyright (c) 2004 Alexander Kern <alex.kern@gmx.de>
+ * Copyright (c) 2003-2006 Richard Lärkäng <nouseforaname@home.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +30,7 @@
 #include <qvbox.h>
 #include <qapplication.h>
 #include <qgroupbox.h>
+#include <qsqlpropertymap.h>
 
 #include <dcopclient.h>
 #include <kaboutdata.h>
@@ -130,6 +132,9 @@ KSCD::KSCD( QWidget *parent, const char *name )
   // the volume slider
   volumeIcon->setPixmap(SmallIcon("player_volume"));
   volumeSlider->setValue(Prefs::volume());
+  QString str;
+  str = QString::fromUtf8( QCString().sprintf(i18n("Vol: %02d%%").utf8(), Prefs::volume()) );
+  volumelabel->setText(str);
   connect(volumeSlider, SIGNAL(valueChanged(int)), SLOT(volChanged(int)));
 
   /* FIXME check for return value */
@@ -137,6 +142,7 @@ KSCD::KSCD( QWidget *parent, const char *name )
   connect(m_cd, SIGNAL(trackPlaying(unsigned, unsigned)), this, SLOT(trackUpdate(unsigned, unsigned)));
   connect(m_cd, SIGNAL(trackPaused(unsigned, unsigned)), this, SLOT(trackUpdate(unsigned, unsigned)));
   connect(m_cd, SIGNAL(trackChanged(unsigned, unsigned)), this, SLOT(trackChanged(unsigned, unsigned)));
+  connect(m_cd, SIGNAL(discStopped()), this, SLOT(discStopped()));
   connect(m_cd, SIGNAL(discChanged(unsigned)), this, SLOT(discChanged(unsigned)));
   connect( &queryledtimer, SIGNAL(timeout()),  SLOT(togglequeryled()) );
   connect( &titlelabeltimer, SIGNAL(timeout()),  SLOT(titlelabeltimeout()) );
@@ -186,6 +192,10 @@ KSCD::KSCD( QWidget *parent, const char *name )
   m_actions->readShortcutSettings("Shortcuts");
   
   m_actions->action( "options_configure_globals" )->setText( i18n( "Configure &Global Shortcuts..." ) );
+
+  kapp->installKDEPropertyMap();
+  QSqlPropertyMap *map = QSqlPropertyMap::defaultMap();
+  map->insert("KComboBox", "currentText");
   
   initGlobalShortcuts();
   
@@ -377,8 +387,6 @@ void KSCD::playClicked()
 
     if (!m_cd->isPlaying())
     {
-        setLEDs(0);
-        resetTimeSlider(true);
         kapp->processEvents();
         kapp->flushX();
 
@@ -389,6 +397,9 @@ void KSCD::playClicked()
         }
         else
         {
+            setLEDs(0);
+            resetTimeSlider(true);
+
             if(Prefs::randomPlay())
             {
                 make_random_list();
@@ -424,6 +435,9 @@ void KSCD::setShuffle(int shuffle)
 {
     if (shuffle == 2) {
         if(Prefs::randomPlay() && m_cd->tracks() > 0) {
+            shufflePB->blockSignals(true);
+            shufflePB->setOn(true);
+            shufflePB->blockSignals(false);
             make_random_list(); /* koz: Build a unique, once, random list */
             if(m_cd->isPlaying())
                 nextClicked();
@@ -459,7 +473,7 @@ void KSCD::prevClicked()
 
     if (Prefs::randomPlay()) {
         track = prev_randomtrack();
-        if (track == 0) {
+        if (track == -1) {
             return;
         }
     } else {
@@ -476,7 +490,7 @@ void KSCD::prevClicked()
 
     kapp->processEvents();
     kapp->flushX();
-    m_cd->play(track, playlist.isEmpty() ? 0 : track);
+    m_cd->play(track, 0, playlist.isEmpty() ? 0 : track);
 } // prevClicked()
 
 bool KSCD::nextClicked()
@@ -504,7 +518,7 @@ bool KSCD::nextClicked()
 
     kapp->processEvents();
     kapp->flushX();
-    m_cd->play(track, playlist.isEmpty() ? 0 : track + 1);
+    m_cd->play(track, 0, Prefs::randomPlay() || !playlist.isEmpty() ? track + 1 : 0);
     return true;
 } // nextClicked()
 
@@ -554,25 +568,25 @@ void KSCD::trackChanged(unsigned track, unsigned trackLength)
 } //trackChanged(int track)
 
 
-void KSCD::jumpToTime(int seconds, bool forcePlay)
+void KSCD::jumpToTime(int ms, bool forcePlay)
 {
     kapp->processEvents();
     kapp->flushX();
 
     int track = m_cd->track();
     if ((m_cd->isPlaying() || forcePlay) &&
-        seconds < (int)m_cd->trackLength())
+        ms < (int)m_cd->trackLength())
     {
         if(Prefs::randomPlay() || !playlist.isEmpty())
         {
-            m_cd->play(track, seconds, track + 1);
+            m_cd->play(track, ms, track + 1);
         }
         else
         {
-            m_cd->play(track, seconds);
+            m_cd->play(track, ms);
         }
     }
-} // jumpToTime(int seconds)
+} // jumpToTime(int ms)
 
 void KSCD::timeSliderPressed()
 {
@@ -751,7 +765,6 @@ void KSCD::showConfig()
 
     updateConfigDialog(confWidget);
 
-    connect(configDialog, SIGNAL(settingsChanged()), confWidget, SLOT(configDone()));
     connect(configDialog, SIGNAL(settingsChanged()), this, SLOT(configDone()));
     configDialog -> show();
 } // showConfig()
@@ -783,21 +796,14 @@ void KSCD::configureGlobalKeys()
 void KSCD::setDevicePaths()
 {
     if (!m_cd->setDevice(Prefs::cdDevice(), Prefs::volume(), Prefs::digitalPlayback(),
-		Prefs::audioSystem(), Prefs::audioDevice()))
+                         Prefs::audioSystem(), Prefs::audioDevice()))
     {
         // This device did not seem usable.
         QString str = i18n("CD-ROM read or access error (or no audio disc in drive).\n"\
                             "Please make sure you have access permissions to:\n%1").arg(
-			      KCompactDisc::urlToDevice(Prefs::cdDevice()));
+                             KCompactDisc::urlToDevice(Prefs::cdDevice()));
         KMessageBox::error(this, str, i18n("Error"));
     }
-    else
-    {
-        if (Prefs::autoplay() && !m_cd->isPlaying())
-        {
-            playClicked();
-        }
-    }
 } // setDevicePath()
 
 void KSCD::setDocking(bool dock)
@@ -854,7 +860,7 @@ void KSCD::decVolume()
 void KSCD::volChanged( int vol )
 {
     QString str;
-    str = QString::fromUtf8( QCString().sprintf(i18n("Vol: %02d%%").utf8(), Prefs::volume()) );
+    str = QString::fromUtf8( QCString().sprintf(i18n("Vol: %02d%%").utf8(), vol) );
     volumelabel->setText(str);
     m_cd->setVolume(vol);
     Prefs::setVolume(vol);
@@ -930,7 +936,6 @@ int KSCD::prev_randomtrack()
     {
         if(!Prefs::looping())
         {
-            m_cd->stop();
             return -1;
         }
         else
@@ -1000,6 +1005,12 @@ void KSCD::discChanged(unsigned discId)
     //totaltimelabel->clear();
     totaltimelabel->lower();
 
+    if ((Prefs::autoplay() || KCmdLineArgs::parsedArgs()->isSet("start"))
+        && !m_cd->isPlaying())
+    {
+        playClicked();
+    }
+
     // We just populated the GUI with what we got from the CD. Now look for
     // more from the Internet...
     lookupCDDB();
@@ -1007,12 +1018,31 @@ void KSCD::discChanged(unsigned discId)
 
 void KSCD::discStopped()
 {
-    statuslabel->setText(i18n("Stopped"));
     if (Prefs::ejectOnFinish() && !stoppedByUser && (m_cd->discId() != KCompactDisc::missingDisc))
     {
         ejectClicked();
     }
 
+    if (!stoppedByUser)
+    {
+      if (Prefs::randomPlay())
+      {
+        // If nextClicked returns false, it was the last
+        // random track, and the player should be stopped
+        if (nextClicked())
+          return;
+      }
+      else if (Prefs::looping())
+      {
+        playClicked();
+        return;
+      }
+    }
+    
+    statuslabel->setText(i18n("Stopped"));
+    playPB->setText(i18n("Play"));
+    playPB->setIconSet(SmallIconSet("player_play"));
+
     /* reset to initial value, only stopclicked() sets this to true */
     stoppedByUser = false;
 
@@ -1180,24 +1210,15 @@ void KSCD::lookupCDDBDone(CDDB::Result result)
       CDInfoList cddb_info = cddb->lookupResponse();
       CDInfoList::iterator it;
       QStringList list;
-      uint defaultChoice = 0;
-      uint maxrev = 0;
-      uint c = 0;
       for ( it = cddb_info.begin(); it != cddb_info.end(); ++it  ) {
         list.append( QString("%1, %2, %3").arg((*it).artist).arg((*it).title)
             .arg((*it).genre));
-        KCDDB::CDInfo cinfo = *it;
-        if ( ( *it ).revision >= maxrev ) {
-          maxrev = info.revision;
-          defaultChoice = c;
-        }
-        c++;
       }
 
       bool ok(false);
       QString res = KInputDialog::getItem(
               i18n("Select CDDB Entry"),
-              i18n("Select a CDDB entry:"), list, defaultChoice, false, &ok,
+              i18n("Select a CDDB entry:"), list, 0, false, &ok,
               this );
       if ( ok ) {
         // The user selected and item and pressed OK
@@ -1332,10 +1353,13 @@ void KSCD::trackUpdate(unsigned /*track*/, unsigned trackPosition)
         tmp = trackPosition;
         break;
     }
-    setLEDs(tmp);
-    timeSlider->blockSignals(true);
-    timeSlider->setValue(trackPosition);
-    timeSlider->blockSignals(false);
+    if (updateTime)
+    {
+      setLEDs(tmp);
+      timeSlider->blockSignals(true);
+      timeSlider->setValue(trackPosition);
+      timeSlider->blockSignals(false);
+    }
 }
 
 void KSCD::cycleplaytimemode()
@@ -1563,6 +1587,8 @@ void KSCD::populateSongList(QString infoStatus)
         str1.append(str2);
         songListCB->insertItem(str1);
     }
+
+    emit trackChanged(m_cd->track(), m_cd->trackLength());
 }
 
 static const KCmdLineOptions options[] =
@@ -1644,7 +1670,6 @@ int main( int argc, char *argv[] )
     }
 
     if (args->count()>0) Prefs::self()->setCdDevice(args->arg(0));
-    if (args->isSet("start")) Prefs::self()->setAutoplay(true);
 
     return a.exec();
 }
